@@ -16,7 +16,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '1.1135'
+    return '1.1136'
 
 
 def f_debug():
@@ -27,31 +27,12 @@ def f_debug():
 
     ----
 
-    - 欢迎您进入Fishconsole的调试控制模块，如果您想了解这个集合是如何运行的，请将mod的参数改为False
-    - 相信我，输出的内容可能会很多，它们能帮你了解这个模块核心组件的全部运行过程，我呢，只是一个职高生，做这
-    - 个完全是为爱发电，所以，虽然我的模块不会很好，但正在努力前行——鱼几斤（2022/4/24）
+    - 欢迎您进入Fishconsole的调试控制模块
+    - 我呢，只是一个职高生，做这
+    - 个完全是为爱发电，所以，虽然我的模块不会很好，但正在努力前行——鱼几斤（2022/6/17）
     ----
-    它管控的有这些
-    ----
-
-    ----
-
-    - 调试模式状态
-    - updata True是激活强制更新，False是关闭更新
-    - FI 系统日志总开关,Ture是开启，False是关闭
-    - pl    False是允许password模块输出消息，True是不允许输出消息
-    - ZUI  False是允许字符串转unicode模块输出消息，True是不允许输出消息
-    - UPI  False是允许强制更新输出消息，Ture是不允许输出消息
-
-
 
     """
-
-    # 它的一切发展都只是为了制作易用中文辅助模块
-
-    # 欢迎您进入Fishconsole的调试控制模块，如果您想了解这个集合是如何运行的，请将mod的参数改为False
-    # ，相信我，输出的内容可能会很多，它们能帮你了解这个模块核心组件的全部运行过程，我呢，只是一个职高生，做这
-    # 个完全是为爱发电，所以，虽然我的模块不会很好，但正在努力前行——鱼几斤（2022/4/24）
     from Fishconsole import logs, files, helps, Fishsys
     try:
         import os, pandas as pd
@@ -89,7 +70,9 @@ def f_debug():
     print("------------")
 
     while True:
+
         b = logs.输入("输入指令以执行")
+
         b = b.split(" ")
         if b[0] == '':
             continue
@@ -143,7 +126,11 @@ def f_debug():
                         "FI": "系统日志总开关",
                         "PI": "passworld系统日志输出控制",
                         "HEI": "helps主程序系统日志输出开关",
-                        "ZUI": "字符串转unicode模块系统日志输出开关"
+                        "ZUI": "字符串转unicode模块系统日志输出开关",
+                        'AC':"系统自动存储的smtp授权码",
+                        'FHUM':"first help updata message",
+                        'FESA':'系统自动存储的邮件发送账号',
+                        'Sender':'系统自动存储的发件人姓名'
 
                     }
                     变量组classification = {
@@ -157,7 +144,11 @@ def f_debug():
                         "FI": "系统日志",
                         "PI": "系统日志",
                         "HEI": "系统日志",
-                        "ZUI": "系统日志"
+                        "ZUI": "系统日志",
+                        "AC":"邮件",
+                        'FHUM':'help弹窗',
+                        'FESA':"邮件",
+                        'Sender':'邮件'
                     }
                     变量组classification = pd.DataFrame(变量组classification.items(), columns=['name', "classification"])
                     变量组info = pd.DataFrame(变量组info.items(), columns=['name', "info about"])
@@ -331,11 +322,27 @@ def f_debug():
                         files.缓存(1, 变量组)
                         break
 
+                if a in  ["AC","ac"]:
+                    未选触发器 = False
+                    计数器=0
+                    try:
+                        smtp授权码=b[2]
+                    except:
+                        print(logs.日志("参数缺失","红色"))
+                    try:
+                        files.缓存(3,数据={"AC":smtp授权码})
+                        print(logs.日志("操作成功", "绿色"))
+                        logs.变量查看("smtp授权码",smtp授权码)
+                    except:
+                        logs.日志("未知错误","红色")
+
+
+
             if 未选触发器:
                 print(logs.分割线(f"这是change的简介", "fcv_debug console", 色选="红色"))
                 print("他的作用就是更改fcv_debug掌管的部分变量的值")
                 print("可用参数")
-                print("Forcedupdate\nUPI\nFI\nPI\nHEI\nZUI")
+                print("Forcedupdate\nUPI\nFI\nPI\nHEI\nZUI\nAC")
                 print("如果想了解具体的用法，请在终端中键入'help'或者'?'")
 
 
@@ -373,8 +380,11 @@ def f_debug():
 
 
         elif b[0] in ["help", "?", "？","HELP"]:
-            helps.帮助()
-
+            def 帮助():
+                from Fishconsole import helps
+                helps.帮助()
+            helps_res = threading.Thread(target=帮助)
+            helps_res.start()
         elif b[0] in ["updata","UPDATA"]:
             print(logs.日志("Fcv_debug Console》我们将尝试激活更新，在程序执行完毕以后，我们将阻止强制更新系统在下一次继续运行","蓝色"))
             files.缓存(3,数据={'updata':True})
@@ -398,8 +408,5 @@ def f_debug():
                 print("他的作用就是调用系统默认的终端来执行指定的内容")
                 print("语法就是 execute + 系统指令")
 
-
-
-
         else:
             print(logs.日志(f"‘{b[0]}’是不受支持的命令，如果想查看命令，请键入'help'或者'?'", 色选="红色"))
