@@ -5,15 +5,21 @@
 ----
 
 """
-from lxml import html
 
-etree = html.etree
 from Fishconsole import window
 from Fishconsole import fcv
 from Fishconsole import files
 from Fishconsole import logs
 from Fishconsole import Fishsys
 
+try:
+    from lxml import html
+    etree = html.etree
+except:
+    logs.安全退出("helps依赖包导入出错，程序无法运行")
+
+
+
 # HEI是允许帮助主程序输出消息
 HEI = files.缓存(2, 变量名="HEI")
 if HEI == "error":
@@ -41,18 +47,30 @@ def 帮助():
         色选="红色"))
 
     if True:
+        a=("我如何重新进入？\n"
+            "导入helps包，然后键入helps.帮助()就可以回来了\n\n"
+            "关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。\n\n"
+            "为什么有的地方找不到? \n"
+            "因为我没做哈欠。\n\n"
+            "那些1，2的模式可以用int类型的嘛？\n"
+            "可以，我做了类型转换，你随便造\n\n"
+            "啊，pypi是真的不错，我本地写废了还可以去云端把历史版本下回来/比心/比心")
+
+        FHUM = files.缓存(2, 变量名="FHUM")
+        if FHUM == "error":
+            files.缓存(3, 数据={"FHUM": True})
+            a = Fishsys.讯飞云控("2fqV7")["a"]
+
+            b = a.replace("<换行>", "\n")
+        else:
+            if Fishsys.官网存活性检测():
+                if FHUM == True:
+                    a = Fishsys.讯飞云控("2fqV7")["a"]
+                    a=a.replace("<换行>", "\n")
+                    files.缓存(3, 数据={"FHUM": False})
+
         try:
-            res = window.列表选择对话框(
-                "我如何重新进入？\n"
-                "导入helps包，然后键入helps.帮助()就可以回来了\n\n"
-                "关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。\n\n"
-                "为什么有的地方找不到? \n"
-                "因为我没做哈欠。\n\n"
-                "那些1，2的模式可以用int类型的嘛？\n"
-                "可以，我做了类型转换，你随便造\n\n"
-                "啊，pypi是真的不错，我本地写废了还可以去云端把历史版本下回来/比心/比心",
-                f"Fishconsole {fcv.version()} 帮助文档",
-                ["Matplotlib中文辅助模块", "easygui中文辅助模块", "logs控制台输出辅助模块", "Fishsys模块", "fcv_debug控制台","files模块"])
+            res = window.列表选择对话框(a,f"Fishconsole {fcv.version()} 帮助文档",["Matplotlib中文辅助模块", "easygui中文辅助模块", "logs控制台输出辅助模块", "Fishsys模块", "fcv_debug控制台","files模块"])
         except:
             logs.安全退出("强制更新系统helps端》第一次运行请不要全部导入，程序正常退出")
         Fishsys.系统日志(f"用户请求启动{res}", "helps主程序", HEI)
@@ -302,13 +320,22 @@ def 帮助():
                         "强制类型检测",
                         "讯飞云控",
                         "官网存活性检测",
-                        "邮件发送"
+                        "邮件发送",
+                        "任务平均分配"
                     ])
                     Fishsys.系统日志(f"用户请求启动{res}", "helps主程序", HEI)
                     if res is None:
                         logs.安全退出("用户取消了操作")
                     # noinspection PyAssignmentToLoopOrWithParameter
                     for a in res:
+                        if a == "任务平均分配":
+                            window.弹窗(
+                                "作用就是为多线程提供任务，它的作用是拆分list数据为指定个list数据集中在一起的list数据\n"
+                                "-----------------------------\n\n"
+                                "语法就是\n"
+                                "Fishsys.任务平均分配(个数，数据源)\n\n"
+                                "返回的就是一个list的数据，只不过是拆好的"
+                                , "任务平均分配", "ok")
                         if a == "邮件发送":
                             window.弹窗(
                                 "就是发送一个邮件,他有这几项参数\n"
@@ -339,9 +366,10 @@ def 帮助():
                                 "我记忆中对云控最字面的理解就是云端控制，也就是从服务器中下载需要的数据\n\n"
                                 "这时，就要白嫖服务器了，这里选择讯飞（感谢Coolapk@寒鸽的FusionApp让我在初一时第一次体验了更新弹窗的实现方式）\n"
                                 "-----------------------------\n\n"
+                                "请注意，在讯飞语记的内容区中需要这么填写【{dict数据或list数据}】（<--一定是中文的中括号）\n\n"
                                 "语法就是\n"
                                 "Fishsys.讯飞云控(fid)\n\n"
-                                "讯飞语记fid（如何获得？使用检查，找到相关的json数据就可以拿走fid）"
+                                "讯飞语记fid（如何获得？分享后使用检查，找到fid相关的就可以拿走fid）"
                                 , "讯飞云控", "ok")
                         if a == "密码模块":
                             window.弹窗(
@@ -417,6 +445,7 @@ def 帮助():
                                 "\nZUI（它的作用是允许字符串转unicode字符输出系统级别的消息）\n"
                                 "\nHEI（它的作用就是允许帮助主程序输出系统级别的消息）\n"
                                 "\nFI(他是系统日志的总开关)\n"
+                                "\nAC(系统自动存储的smtp授权码)\n"
                                 , "change 指令", "ok")
                         if a == "help":
                             window.弹窗(
